Unification Mainnet Helpers
===========================

Miscellaneous tools to help support the provisioning and maintance of EV
can be found here.

Revert
------

To revert all data, fetch the latest binary, and uses the lastest
published genesis. Warning, this will destroy your chain data and
catching up may take a while.

    python -m mainchain.upgrade revert

Network upgrades
----------------

There is also a helper that support network upgrades

    python -m mainchain.upgrade genesis 700000

The helper will wait until the specified block and then perform an
upgrade.
